summaryrefslogtreecommitdiffstats
path: root/knotes/knote.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knotes/knote.cpp')
-rw-r--r--knotes/knote.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/knotes/knote.cpp b/knotes/knote.cpp
index 9e644d7a6..d4ce67b50 100644
--- a/knotes/knote.cpp
+++ b/knotes/knote.cpp
@@ -202,17 +202,17 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
m_editor->setCornerWidget( new TQSizeGrip( this ) );
uint width = m_editor->cornerWidget()->width();
uint height = m_editor->cornerWidget()->height();
- TQBitmap mask;
- mask.resize( width, height );
- mask.fill( color0 );
+ TQBitmap tqmask;
+ tqmask.resize( width, height );
+ tqmask.fill( color0 );
TQPointArray array;
array.setPoints( 3, 0, height, width, height, width, 0 );
TQPainter p;
- p.begin( &mask );
+ p.begin( &tqmask );
p.setBrush( color1 );
p.drawPolygon( array );
p.end();
- m_editor->cornerWidget()->setMask( mask );
+ m_editor->cornerWidget()->setMask( tqmask );
m_editor->cornerWidget()->setBackgroundMode( PaletteBase );
// the config file location
@@ -321,7 +321,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
// read configuration settings...
slotApplyConfig();
// create the mask for the fold---to be done after slotApplyConfig(),
// which calls createFold()
m_fold->setMask( TQRegion( m_fold->pixmap()->createHeuristicMask() ) );
@@ -774,7 +774,7 @@ void KNote::slotClose()
void KNote::slotInsDate()
{
- m_editor->insert( KGlobal::locale()->formatDateTime(TQDateTime::currentDateTime()) );
+ m_editor->insert( KGlobal::locale()->formatDateTime(TQDateTime::tqcurrentDateTime()) );
}
void KNote::slotSetAlarm()
@@ -861,7 +861,7 @@ void KNote::slotPrint()
printer.setFont( m_config->font() );
printer.setContext( m_editor->context() );
printer.setStyleSheet( m_editor->styleSheet() );
- printer.setColorGroup( colorGroup() );
+ printer.tqsetColorGroup( tqcolorGroup() );
printer.printNote( TQString(), content );
}
@@ -1035,9 +1035,9 @@ void KNote::updateLabelAlignment()
// if the name is too long to fit, left-align it, otherwise center it (#59028)
TQString labelText = m_label->text();
if ( m_label->fontMetrics().boundingRect( labelText ).width() > m_label->width() )
- m_label->setAlignment( AlignLeft );
+ m_label->tqsetAlignment( AlignLeft );
else
- m_label->setAlignment( AlignHCenter );
+ m_label->tqsetAlignment( AlignHCenter );
}
void KNote::updateFocus()
@@ -1100,7 +1100,7 @@ void KNote::updateMask()
int h = height();
TQRegion reg( 0, s_ppOffset, w, h - s_ppOffset );
- const TQBitmap *pushpin_bitmap = m_pushpin->pixmap()->mask();
+ const TQBitmap *pushpin_bitmap = m_pushpin->pixmap()->tqmask();
TQRegion pushpin_reg( *pushpin_bitmap );
m_pushpin->setMask( pushpin_reg );
pushpin_reg.translate( m_pushpin->x(), m_pushpin->y() );
@@ -1120,7 +1120,7 @@ void KNote::updateBackground( int y_offset )
{
if ( !s_ppOffset )
{
- m_editor->setPaper( TQBrush( colorGroup().background() ) );
+ m_editor->setPaper( TQBrush( tqcolorGroup().background() ) );
return;
}
@@ -1160,7 +1160,7 @@ void KNote::updateBackground( int y_offset )
void KNote::updateLayout()
{
- const int headerHeight = m_label->sizeHint().height();
+ const int headerHeight = m_label->tqsizeHint().height();
const int margin = m_editor->margin();
bool closeLeft = false;
@@ -1240,9 +1240,9 @@ void KNote::drawFrame( TQPainter *p )
TQRect r = frameRect();
r.setTop( s_ppOffset );
if ( s_ppOffset )
- qDrawShadePanel( p, r, colorGroup(), false, lineWidth() );
+ qDrawShadePanel( p, r, tqcolorGroup(), false, lineWidth() );
else
- qDrawWinPanel( p, r, colorGroup(), false );
+ qDrawWinPanel( p, r, tqcolorGroup(), false );
}
void KNote::showEvent( TQShowEvent * )
@@ -321,7 +321,7 @@ KNote::KNote( TQDomDocument buildDoc, Journal *j, TQWidget *parent, const char *
// read configuration settings...
slotApplyConfig();
- // create the mask for the fold---to be done after slotApplyConfig(),
+ // create the tqmask for the fold---to be done after slotApplyConfig(),
// which calls createFold()
m_fold->setMask( TQRegion( m_fold->pixmap()->createHeuristicMask() ) );